<?php

namespace NewsModule;

use \dibi;
use \SimplePie;
use Nette\Environment;

class NewsReaderBase extends \Nette\Object {

    const HALF_HOUR = 1800;
    const FIVE_MINUTES = 300;

    protected $categories = array();
    private $feed;
    protected $key = null;
    protected $logo = null;
    protected $supportedCountryCodes = array();
    protected $query_base;
    protected $query_postfix = "";

    public function __construct() {
        $this->feed = new SimplePie;
        $this->feed->enable_cache(true);
        if (!is_dir(Environment::getVariable("tempDir") . "/rsscache")) {
            mkdir(Environment::getVariable("tempDir") . "/rsscache");
        }
        $this->feed->set_cache_location(Environment::getVariable("tempDir") . "/rsscache");
        $this->feed->set_cache_duration(1800);
    }

    public function getKey() {
        return $this->key;
    }

    public function getCategories() {
        return $this->categories;
    }

    public function getCategory($category_id) {
        $categories = $this->getCategories();
        return $categories[$category_id];
    }

    public function getLogo() {
        return "/www/apps/news/logos/" . $this->logo;
    }

    public function fetchNews($category) {

        // if we want top news, fetch from DB
        if ($category === "top") {
            $top_rated = dibi::select("*")->from("news")->orderBy(array("rating" => dibi::DESC))->fetchAll();
            return array("items" => $top_rated);
        }

        if (array_key_exists($category, $this->categories)) {
            $url = $this->getUrl($category);
        } else {
            return array();
        }

        $this->initRss($url);

        return $this->parseNews();
    }

    public function getStory($guid, $category_id) {
        if (array_key_exists($category_id, $this->categories)) {
            $url = $this->getUrl($category_id);
        } else {
            throw new \Exception("Unsupported news category");
        }
        $this->initRss($url);
        foreach ($this->feed->get_items() as $item) {



            $pictures = $this->getImages($item);
            if (empty($pictures)) {
                $pictures[] = array(
                    "link" => "http://www.liveautoauction.com.cy/carthmbnails/no_image.gif",
                    "title" => ""
                );
            }


            if ($item->get_id() == $guid) {
                $article = array();
                $article["guid"] = $guid;
                $article["pubdate"] = date("j.m. Y", $item->get_date("U"));
//                $article["pubdate"] = \Celebrio\Util\DateParser::getFullDateFromTimestamp($item->get_date("U"));
                $article["publisher"] = "ČT";
                $article["category"] = $category_id;
                $article["title"] = $item->get_title();
                $article["link"] = $item->get_link();
                //$article["picture"] = $item->get_enclosure()->get_link();
                $article["pictures"] = $pictures;
                $article["content"] = $this->getContent($item);
                $article["logo"] = $this->getLogo();
                return $article;
            }
        }

        throw new \Exception("Story not found. It's probably not in the cache or DB.");
    }

    public function rateArticle($article_array) {
        $article = Article::fromArray($article_array);
        $idLanguage = $this->manageLanguage("cs_cz");
        $article->rate($idLanguage);
    }

    // -------- private section --------- //

    private function initRss($url) {
        $this->feed->set_feed_url($url);
        $this->feed->init();
        $this->feed->handle_content_type();
    }

    private function parseNews() {
        $result = array();
        $result["title"] = $this->feed->get_title();
        $result["copyright"] = $this->feed->get_copyright();
        $result["logo"] = $this->getLogo();
        $result["items"] = array();
        foreach ($this->feed->get_items() as $item) {



            $picture = $this->getMainImage($item);
            if ($picture == null) {
                $picture = "http://www.liveautoauction.com.cy/carthmbnails/no_image.gif"; //temporary
            }


            $result["items"][] = array(
                "guid" => $item->get_id(),
                "title" => $item->get_title(),
                "publisher" => $item->get_contributor(),
                "link" => $item->get_link(),
                "category" => $item->get_category(),
                "pubdate" => $item->get_date(),
                "pubtimestamp" => $item->get_date("U"),
                "picture" => $picture,
                "content" => $this->getContent($item),
                "reader" => $this->key,
                "logo" => $this->getLogo(),
            );
        }
        //"content" => strip_tags($item->description,"<a><b><br><nobr>")
        //"content" => str_replace('size="-2"',"",str_replace('size="-1"',"",str_replace("font-size:85%;","",$item->description)))
        return $result;
    }

    private function manageLanguage($countryCode) {
        $id = dibi::select("id_language")->from("languages")->where(array("language" => $countryCode))->fetch();
        if (!$id) {
            dibi::insert("languages", array("language" => $countryCode))->execute();
            return dibi::getInsertId();
        } else {
            return $id["id_language"];
        }
    }

    private function getUrl($category) {
        return $this->query_base . $this->categories[$category]["url"] . $this->query_postfix;
    }

    protected function getImages($item) {
        $pictures = array();
        foreach ($item->get_enclosures() as $enclosure) {
            if (( (int) $enclosure->get_length() ) > 10000) {
                $pictures[] = array(
                    "link" => $enclosure->get_link(),
                    "title" => $enclosure->get_title()
                );
            }
        }
        return $pictures;
    }

    protected function getMainImage($item) {
        $size = -1;
        $picture = null;

        foreach ($item->get_enclosures() as $pict) {
            $pict_len = $pict->get_length();
            if ($pict_len > $size) {
                $size = $pict_len;
                $picture = $pict->get_link();
            }
        }

        return $picture;
    }

    protected function getContent($item) {
        return $item->get_content();
    }

}
